@@ -177,7 +177,7 @@ def handle_build_requests(poll_timeout: int, running_limit: int) -> None:
         return
 
     broker = CBMessageBroker.new(
-        'kafka', config_file=Defaults.get_kafka_config()
+        'kafka', config_file=Defaults.get_broker_config()
     )
     try:
         while(True):
@@ -186,8 +186,7 @@ def handle_build_requests(poll_timeout: int, running_limit: int) -> None:
                 log.info('Max running builds limit reached')
                 break
             for message in broker.read(
-                Defaults.get_package_request_queue_name(),
-                timeout_ms=poll_timeout
+                topic=broker.get_runner_group(), timeout_ms=poll_timeout
             ):
                 request = broker.validate_package_request(message.value)
                 if request:
@@ -224,15 +223,20 @@ def build_package(
         request, log, broker
     )
     status_flags = Defaults.get_status_flags()
-    if request['action'] == status_flags.package_changed:
+    if request['action'] == status_flags.package_changed or \
+       request['action'] == status_flags.package_and_meta_changed:
         log.info('Update project git source repo prior build')
         Command.run(
             ['git', '-C', Defaults.get_runner_project_dir(), 'pull']
         )
 
+    buildroot_rebuild = False
+    if request['action'] == status_flags.package_and_meta_changed:
+        buildroot_rebuild = True
+
     log.info('Starting build process')
     Command.run(
-        ['bash', create_run_script(request)]
+        ['bash', create_run_script(request, buildroot_rebuild)]
     )
 
 
@@ -297,7 +301,7 @@ def is_request_valid(
 
     1. Check if given package source exists
     2. Check if there is a cloud builder metadata and kiwi file
-    3. Check if architecture + dist is configured in the metadata
+    3. Check if architecture + dist + runner_group is configured in the metadata
     4. Check if the host architecture is compatbile with the
        request architecture
 
@@ -341,18 +345,22 @@ def is_request_valid(
     target_ok = False
     request_arch = request['arch']
     request_dist = request['dist']
+    request_runner_group = request['runner_group']
     package_config = CBPackageMetaData.get_package_config(
         package_source_path, log, request['request_id']
     )
     if package_config:
         for target in package_config.get('distributions') or []:
             if request_arch == target.get('arch') and \
-               request_dist == target.get('dist'):
+               request_dist == target.get('dist') and \
+               request_runner_group == target.get('runner_group'):
                 target_ok = True
                 break
     if not target_ok:
         response.set_package_invalid_target_response(
-            message=f'No build dist config for: {request_dist}.{request_arch}',
+            message='No build config for: {0}.{1} in runner group {2}'.format(
+                request_dist, request_arch, request_runner_group
+            ),
             response_code=status_flags.package_target_not_configured,
             package=request['package']
         )
@@ -382,12 +390,13 @@ def is_request_valid(
     return package_config
 
 
-def create_run_script(request: Dict) -> str:
+def create_run_script(request: Dict, buildroot_rebuild: bool) -> str:
     """
     Create script to call cb-prepare followed by cb-run
     for each configured distribution/arch
 
     :param dict request: yaml dict request record
+    :param bool buildroot_rebuild: rebuild buildroot True|False
 
     :return: file path name for script
 
@@ -408,6 +417,10 @@ def create_run_script(request: Dict) -> str:
 
         rm -f {target_root}.log
 
+        if {buildroot_rebuild}; then
+            rm -rf {target_root}
+        fi
+
         function finish {{
             kill $(jobs -p) &>/dev/null
         }}
@@ -424,6 +437,7 @@ def create_run_script(request: Dict) -> str:
 
         echo $! > {target_root}.pid
     ''').format(
+        buildroot_rebuild='true' if buildroot_rebuild else 'false',
         runner_root=Defaults.get_runner_package_root(),
         package_source_path=package_source_path,
         dist_profile=dist_profile,
